@@ -7,23 +7,27 @@ function(ensembleData, trainingDays, consecutive = FALSE, dates = NULL,
  mc <- match.call()
  mc$model <- NULL
 
-## if (!is.null(model)) {
-##   MODELS <- c("normal","gamma0")
-##   m <- pmatch( model, MODELS, nomatch=0)
-##   model <- if (m) MODELS[m] else "?"
-##}
-##else stop("unspecified model")
-
-  switch( model,
+ if (!is.null(model)) {
+   switch( model,
         "normal" = {
              mc[[1]] <- as.name("ensembleMOSnormal")
           },
-        "normal0" = {
-             mc[[1]] <- as.name("ensembleMOSnormal0")
+        "truncnormal" = {
+             mc[[1]] <- as.name("ensembleMOStruncnormal")
           },
+        "lognormal" = {
+          mc[[1]] <- as.name("ensembleMOSlognormal")
+        },
+        "csg0" = {
+          mc[[1]] <- as.name("ensembleMOScsg0")
+        },
+        "gev0" = {
+          mc[[1]] <- as.name("ensembleMOSgev0")
+        },
         stop("unrecognized model")
     )
-
+ } else stop("unspecified model")
+ 
  if (length(attr(ensembleData, "class")) > 2) {
    attr(ensembleData, "class") <- attr(ensembleData, "class")[-1]
    mc$ensembleData <- ensembleData
